# -*- coding: utf-8 -*-
# Create your views here.
import django.views.generic as gviews
from django.views.generic.edit import FormMixin, TemplateResponseMixin

## Class generique permettant de filtrer une liste
class ListFilter(FormMixin, TemplateResponseMixin, gviews.View):

    def get_form_kwargs(self, *args, **kwargs):
        kwargs = {
            'initial': self.get_initial(),
#            'request': self.request,
            }
        if 'submit' in self.request.GET:
            kwargs.update({
                    'data': self.request.GET,
                    })
        return kwargs

    def get_initial(self):
        return self.request.GET

    def form_valid(self, form):
        ctx = self.get_context_data(form=form)
        ctx.update(self.process_search_form(form))
        return self.render_to_response(ctx)

    def get(self, request, *args, **kwargs):
        form_class = self.get_form_class()
        form = self.get_form(form_class)
        if 'submit' in self.request.GET:
            if form.is_valid():
                return self.form_valid(form)
            else:
                return self.form_invalid(form)
        else:
            return self.render_to_response(self.get_context_data(form=form))

    @staticmethod
    def _build_lookup_set(form, filter_value_set):
        lookup_filter_set = {}
        for field, lookup, force_val in filter_value_set:
            value = form.cleaned_data.get(field)
            if value:
                if force_val and force_val[0] == value:
                    lookup_filter_set[lookup] = force_val[1]
                else:
                    lookup_filter_set[lookup] = value
        return lookup_filter_set

    def process_search_form(self, form):
        "dummy method that must return a context"
        base_qs = self.get_queryset()
        base_qs = (base_qs
                   .filter(**self._build_lookup_set(form, form.filter_set))
                   .exclude(**self._build_lookup_set(form, form.exclude_set))
                   )
#        base_qs = (base_qs
#                   .filter(*form.construit_filtres_qs(form.cleaned_data))
#                   .distinct())
        return {
            'object_list': base_qs,
            'submit': True,
            }

    def get_queryset(self):
        return self.model.objects.all()

# EOF
