from django.contrib.auth import models as am
from django.core.exceptions import ValidationError
from django.test import TestCase

from contacts import models as cm
from contacts.tests.utils import mfty, cfty
from references import models as rm


class ValDonnees(TestCase):

    def setUp(self):
        self.usr1 = am.User.objects.create_user('usr1')
        self.fjur = rm.FormeJuridique()
        self.fjur.save()
        self.i_pm = {
            'date_creation': '2014-10-01',
            'date_derniere_modification': '2014-10-02',
            'utilisateur_derniere_modification': self.usr1,
            'f_juridique': self.fjur,
            'designation': "test",
            'type_pm': 1,
            }
        self.i_donnees = {
            'agriculteur_bio': cfty(cm.Structure, self.i_pm)
            }

    def test_lait_vache(self):
        """ Si un nombre de vache laitiere est entre, il faut preciser si la production est bio"""
        # Nombre de vache saisie mais la valeur bio est inchange avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, lait_nb_vaches = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de vache saisie et la valeur bio est change sans erreur
        donnees.lait_vaches = False
        try:
            donnees.full_clean()
        except ValidationError:
            self.fail("ne devrait pas foirer")


    def test_lait_chevre(self):
        """ Si un nombre de chevre est entre, il faut preciser si la production est bio"""
        # Nombre de chevre saisi mais la valeur bio est inchange avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, lait_nb_chevres = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de chevre saisi et la valeur bio est change sans erreur
        donnees.lait_chevres = True
        donnees.full_clean()

    def test_viande_bovine(self):
        """ Si un des champs bovine_nb_va, bovine_nb_conversion,
        bovine_reformes_cl, bovine_taurillons_cl, bovine_adultes_cc ou
        bovine_veaux_cc est complete il faut indiquer si la production
        est bio"""
        # Nombre de bovins saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, bovine_nb_va = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de bovins saisi et valeur bio changee sans erreur
        donnees.bovine = True
        donnees.full_clean()
        # Nombre de bovins en conversion saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, bovine_nb_conversion = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de bovins en conversion saisi et valeur bio changee sans erreur
        donnees.bovine = True
        donnees.full_clean()
        # Nombre de bovins en CL saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, bovine_reformes_cl = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de bovins en CL saisi et valeur bio changee sans erreur
        donnees.bovine = True
        donnees.full_clean()
        # Nombre de veaux en CL saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, bovine_taurillons_cl = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de veaux en CL saisi et valeur bio changee sans erreur
        donnees.bovine = True
        donnees.full_clean()
        # Nombre de bovins en CC saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, bovine_adultes_cc = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de bovins en CC saisi et valeur bio changee sans erreur
        donnees.bovine = True
        donnees.full_clean()
        # Nombre de veaux en CC saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, bovine_veaux_cc = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de veaux en CC saisi et valeur bio changee sans erreur
        donnees.bovine = True
        donnees.full_clean()

    def test_viande_porc(self):
        """ Si un nombre de truies est saisi ou si un nombre de porc commercialise est saisi il faut
        indiquer si la production est bio"""
        # Nombre de truies saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, porcs_nb_truies = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de truies saisi et valeur bio changee sans erreur
        donnees.porcs = True
        donnees.full_clean()
        # Nombre de porcs commercialise saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, porcs_nb_com = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de porcs commercialise saisi et valeur bio changee sans erreur
        donnees.porcs = True
        donnees.full_clean()

    def test_mouton(self):
        """ Si un nombre de brebis est saisi il faut
        indiquer si la production est bio"""
        # Nombre de brebis saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, moutons_nb_brebis = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de truies saisi et valeur bio changee sans erreur
        donnees.moutons = True
        donnees.full_clean()

    def test_lapin(self):
        """ Si un nombre de lapin est saisi il faut
        indiquer si la production est bio"""
        # Nombre de lapin saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, animaux_nb_lapins = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de lapin saisi et valeur bio changee sans erreur
        donnees.animaux_lapins = True
        donnees.full_clean()

    def test_volaille(self):
        """ Si un nombre de poulet ou un nombre d'autre volaille est saisi il faut
        indiquer si la production est bio"""
        # Nombre de poulet saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, animaux_nb_poulets = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de poulet saisi et valeur bio changee sans erreur
        donnees.animaux_volailles = True
        donnees.full_clean()
        # Nombre d'autre volaille saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, animaux_nb_autres_volailles = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre d'autre volaille saisi et valeur bio changee sans erreur
        donnees.animaux_volailles = True
        donnees.full_clean()

    def test_oeuf(self):
        """ Si un nombre de pondeuse est saisi il faut
        indiquer si la production est bio"""
        # Nombre de pondeuse saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, oeufs_nb_pondeuses = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de pondeuse saisi et valeur bio changee sans erreur
        donnees.oeufs_production_bio = True
        donnees.full_clean()

    def test_autre_produit(self):
        """ Si une autre production animale est renseigne il faut
        indiquer si la production est bio"""
        # Autre production saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, animaux_details_autres_prod = "test")
        self.assertRaises(ValidationError, donnees.full_clean)
        # Autre production saisi et valeur bio changee sans erreur
        donnees.animaux_autres_prod = True
        donnees.full_clean()

    def test_miel(self):
        """ Si un nombre de ruche est saisi il faut
        indiquer si la production est bio"""
        # Nombre de ruche saisi mais valeur bio inchangee avec erreur
        donnees = mfty(cm.DonneesBio, self.i_donnees, miel_nb_ruches = 1)
        self.assertRaises(ValidationError, donnees.full_clean)
        # Nombre de ruche saisi et valeur bio changee sans erreur
        donnees.miel_production_bio = True
        donnees.full_clean()
        
# EOF
