# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):
    
    def forwards(self, orm):
        
        # Adding model 'Zone'
        db.create_table('references_zone', (
            ('nom', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
        ))
        db.send_create_signal('references', ['Zone'])

        # Adding model 'PetiteRegionAgricole'
        db.create_table('references_petiteregionagricole', (
            ('departement', self.gf('django.db.models.fields.CharField')(max_length=3)),
            ('nom', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('code', self.gf('django.db.models.fields.IntegerField')(unique=True)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('grande_region', self.gf('django.db.models.fields.IntegerField')()),
        ))
        db.send_create_signal('references', ['PetiteRegionAgricole'])

        # Adding model 'Arrondissement'
        db.create_table('references_arrondissement', (
            ('departement', self.gf('django.db.models.fields.IntegerField')()),
            ('nom', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('region', self.gf('django.db.models.fields.IntegerField')()),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('numero', self.gf('django.db.models.fields.IntegerField')()),
        ))
        db.send_create_signal('references', ['Arrondissement'])

        # Adding unique constraint on 'Arrondissement', fields ['numero', 'departement']
        db.create_unique('references_arrondissement', ['numero', 'departement'])

        # Adding model 'Canton'
        db.create_table('references_canton', (
            ('arrondissement', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['references.Arrondissement'])),
            ('nom', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('numero', self.gf('django.db.models.fields.IntegerField')()),
        ))
        db.send_create_signal('references', ['Canton'])

        # Adding unique constraint on 'Canton', fields ['numero', 'arrondissement']
        db.create_unique('references_canton', ['numero', 'arrondissement_id'])

        # Adding model 'Commune'
        db.create_table('references_commune', (
            ('nom', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('code_postal', self.gf('django.db.models.fields.CharField')(max_length='15', null=True, blank=True)),
            ('petite_region', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['references.PetiteRegionAgricole'])),
            ('zone', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['references.Zone'])),
            ('arrondissement', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['references.Arrondissement'])),
            ('code_commune', self.gf('django.db.models.fields.CharField')(max_length='15', null=True, blank=True)),
            ('enjeu_eau', self.gf('django.db.models.fields.NullBooleanField')(null=True, blank=True)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
        ))
        db.send_create_signal('references', ['Commune'])

        # Adding M2M table for field cantons on 'Commune'
        db.create_table('references_commune_cantons', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('commune', models.ForeignKey(orm['references.commune'], null=False)),
            ('canton', models.ForeignKey(orm['references.canton'], null=False))
        ))
        db.create_unique('references_commune_cantons', ['commune_id', 'canton_id'])

        # Adding model 'StatutStructure'
        db.create_table('references_statutstructure', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['StatutStructure'])

        # Adding model 'FormeJuridique'
        db.create_table('references_formejuridique', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['FormeJuridique'])

        # Adding model 'TypeActivite'
        db.create_table('references_typeactivite', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['TypeActivite'])

        # Adding model 'AutreQualificatifExploitation'
        db.create_table('references_autrequalificatifexploitation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['AutreQualificatifExploitation'])

        # Adding model 'Laiterie'
        db.create_table('references_laiterie', (
            ('nom', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
        ))
        db.send_create_signal('references', ['Laiterie'])

        # Adding model 'OrganismeDeCertification'
        db.create_table('references_organismedecertification', (
            ('nom', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
        ))
        db.send_create_signal('references', ['OrganismeDeCertification'])

        # Adding model 'Etiquette'
        db.create_table('references_etiquette', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length='255', null=True, blank=True)),
        ))
        db.send_create_signal('references', ['Etiquette'])

        # Adding model 'StatutCommercialisation'
        db.create_table('references_statutcommercialisation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['StatutCommercialisation'])

        # Adding model 'TypeService'
        db.create_table('references_typeservice', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['TypeService'])

        # Adding model 'Culture'
        db.create_table('references_culture', (
            ('indice_ordre', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
            ('categorie', self.gf('django.db.models.fields.CharField')(max_length='100')),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['Culture'])

        # Adding model 'ClientCulture'
        db.create_table('references_clientculture', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['ClientCulture'])

        # Adding model 'Abattoir'
        db.create_table('references_abattoir', (
            ('nom', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
        ))
        db.send_create_signal('references', ['Abattoir'])

        # Adding model 'AcheteurOeufs'
        db.create_table('references_acheteuroeufs', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['AcheteurOeufs'])

        # Adding model 'Formation'
        db.create_table('references_formation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['Formation'])

        # Adding model 'TypeFormation'
        db.create_table('references_typeformation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['TypeFormation'])

        # Adding model 'FinanceProg'
        db.create_table('references_financeprog', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('designation', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('references', ['FinanceProg'])
    
    
    def backwards(self, orm):
        
        # Deleting model 'Zone'
        db.delete_table('references_zone')

        # Deleting model 'PetiteRegionAgricole'
        db.delete_table('references_petiteregionagricole')

        # Deleting model 'Arrondissement'
        db.delete_table('references_arrondissement')

        # Removing unique constraint on 'Arrondissement', fields ['numero', 'departement']
        db.delete_unique('references_arrondissement', ['numero', 'departement'])

        # Deleting model 'Canton'
        db.delete_table('references_canton')

        # Removing unique constraint on 'Canton', fields ['numero', 'arrondissement']
        db.delete_unique('references_canton', ['numero', 'arrondissement_id'])

        # Deleting model 'Commune'
        db.delete_table('references_commune')

        # Removing M2M table for field cantons on 'Commune'
        db.delete_table('references_commune_cantons')

        # Deleting model 'StatutStructure'
        db.delete_table('references_statutstructure')

        # Deleting model 'FormeJuridique'
        db.delete_table('references_formejuridique')

        # Deleting model 'TypeActivite'
        db.delete_table('references_typeactivite')

        # Deleting model 'AutreQualificatifExploitation'
        db.delete_table('references_autrequalificatifexploitation')

        # Deleting model 'Laiterie'
        db.delete_table('references_laiterie')

        # Deleting model 'OrganismeDeCertification'
        db.delete_table('references_organismedecertification')

        # Deleting model 'Etiquette'
        db.delete_table('references_etiquette')

        # Deleting model 'StatutCommercialisation'
        db.delete_table('references_statutcommercialisation')

        # Deleting model 'TypeService'
        db.delete_table('references_typeservice')

        # Deleting model 'Culture'
        db.delete_table('references_culture')

        # Deleting model 'ClientCulture'
        db.delete_table('references_clientculture')

        # Deleting model 'Abattoir'
        db.delete_table('references_abattoir')

        # Deleting model 'AcheteurOeufs'
        db.delete_table('references_acheteuroeufs')

        # Deleting model 'Formation'
        db.delete_table('references_formation')

        # Deleting model 'TypeFormation'
        db.delete_table('references_typeformation')

        # Deleting model 'FinanceProg'
        db.delete_table('references_financeprog')
    
    
    models = {
        'references.abattoir': {
            'Meta': {'object_name': 'Abattoir'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nom': ('django.db.models.fields.CharField', [], {'max_length': '250'})
        },
        'references.acheteuroeufs': {
            'Meta': {'object_name': 'AcheteurOeufs'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.arrondissement': {
            'Meta': {'unique_together': "(('numero', 'departement'),)", 'object_name': 'Arrondissement'},
            'departement': ('django.db.models.fields.IntegerField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nom': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'numero': ('django.db.models.fields.IntegerField', [], {}),
            'region': ('django.db.models.fields.IntegerField', [], {})
        },
        'references.autrequalificatifexploitation': {
            'Meta': {'object_name': 'AutreQualificatifExploitation'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.canton': {
            'Meta': {'unique_together': "(('numero', 'arrondissement'),)", 'object_name': 'Canton'},
            'arrondissement': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['references.Arrondissement']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nom': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'numero': ('django.db.models.fields.IntegerField', [], {})
        },
        'references.clientculture': {
            'Meta': {'object_name': 'ClientCulture'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.commune': {
            'Meta': {'object_name': 'Commune'},
            'arrondissement': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['references.Arrondissement']"}),
            'cantons': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['references.Canton']", 'null': 'True', 'blank': 'True'}),
            'code_commune': ('django.db.models.fields.CharField', [], {'max_length': "'15'", 'null': 'True', 'blank': 'True'}),
            'code_postal': ('django.db.models.fields.CharField', [], {'max_length': "'15'", 'null': 'True', 'blank': 'True'}),
            'enjeu_eau': ('django.db.models.fields.NullBooleanField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nom': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'petite_region': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['references.PetiteRegionAgricole']"}),
            'zone': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['references.Zone']"})
        },
        'references.culture': {
            'Meta': {'object_name': 'Culture'},
            'categorie': ('django.db.models.fields.CharField', [], {'max_length': "'100'"}),
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'indice_ordre': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'})
        },
        'references.etiquette': {
            'Meta': {'object_name': 'Etiquette'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': "'255'", 'null': 'True', 'blank': 'True'}),
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.financeprog': {
            'Meta': {'object_name': 'FinanceProg'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.formation': {
            'Meta': {'object_name': 'Formation'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.formejuridique': {
            'Meta': {'object_name': 'FormeJuridique'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.laiterie': {
            'Meta': {'object_name': 'Laiterie'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nom': ('django.db.models.fields.CharField', [], {'max_length': '250'})
        },
        'references.organismedecertification': {
            'Meta': {'object_name': 'OrganismeDeCertification'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nom': ('django.db.models.fields.CharField', [], {'max_length': '250'})
        },
        'references.petiteregionagricole': {
            'Meta': {'object_name': 'PetiteRegionAgricole'},
            'code': ('django.db.models.fields.IntegerField', [], {'unique': 'True'}),
            'departement': ('django.db.models.fields.CharField', [], {'max_length': '3'}),
            'grande_region': ('django.db.models.fields.IntegerField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nom': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'references.statutcommercialisation': {
            'Meta': {'object_name': 'StatutCommercialisation'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.statutstructure': {
            'Meta': {'object_name': 'StatutStructure'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.typeactivite': {
            'Meta': {'object_name': 'TypeActivite'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.typeformation': {
            'Meta': {'object_name': 'TypeFormation'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.typeservice': {
            'Meta': {'object_name': 'TypeService'},
            'designation': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'references.zone': {
            'Meta': {'object_name': 'Zone'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nom': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        }
    }
    
    complete_apps = ['references']
